fetch(
  'https://gist.githubusercontent.com/Prathi0410/46d02f90deac8ae8c843c7c4fef9d0a8/raw/a26ae0e5e3fa187d17001c17ac426689589873b8/ICE6-Assignment%2520Data-final',
)
  .then((response) => response.text())
  .then((data) => {
    const rows = data.split('\n').slice(1); // Remove header row
    const names = [];
    const salesVolumes = [];
    const colors = [];
    for (const row of rows) {
      const [, name, , , salesVolume] = row.split(',');
      names.push(name);
      salesVolumes.push(parseFloat(salesVolume));
      colors.push(getRandomColor());
    }

    var pieChart = new Chart(
      document.getElementById('pieChart'),
      {
        type: 'pie',
        data: {
          labels: names,
          datasets: [
            {
              label: 'Sales Volume by Item',
              data: salesVolumes,
              backgroundColor: colors,
              borderWidth: 0,
            },
          ],
        },
        options: {
          responsive: true,
          plugins: {
            legend: {
              position: 'right',
              labels: {
                // Customize legend label
                generateLabels: function (chart) {
                  const data = chart.data;
                  if (
                    data.labels.length &&
                    data.datasets.length
                  ) {
                    return data.labels.map(
                      function (label, i) {
                        const meta =
                          chart.getDatasetMeta(0);
                        const ds = data.datasets[0];
                        const arc = meta.data[i];
                        const custom = {
                          text:
                            label +
                            ' - ' +
                            ds.data[i] +
                            ' units',
                          fillStyle: ds.backgroundColor[i],
                          // Include hidden attribute to hide items initially
                          hidden: chart
                            ? !chart.isDatasetVisible(0)
                            : false,
                          // Override text width to prevent the label from being cut off
                          lineCap: 'round',
                          lineDash: [],
                          lineDashOffset: 0.0,
                          lineJoin: 'round',
                          lineWidth: 0,
                          strokeStyle:
                            ds.backgroundColor[i],
                          // Extra data used for toggling the correct item
                          index: i,
                        };
                        return custom;
                      },
                    );
                  } else {
                    return [];
                  }
                },
              },
            },
            title: {
              display: true,
              text: 'Sales Volume by Item',
            },
            tooltip: {
              callbacks: {
                label: function (context) {
                  return (
                    context.label +
                    ': ' +
                    context.raw +
                    ' units'
                  );
                },
              },
            },
          },
        },
      },
    );
  })
  .catch((error) =>
    console.error('Error fetching data:', error),
  );

// Function to generate a random color
function getRandomColor() {
  const letters = '0123456789ABCDEF';
  let color = '#';
  for (let i = 0; i < 6; i++) {
    color += letters[Math.floor(Math.random() * 16)];
  }
  return color;
}
